Module capability

Module capability 

Structs

FeatureSupport
A feature that can be either natively supported by the provider or implemented by the wrapper.
Features
All feature flags for a provider.
ProviderCapability
Full capability declaration for a provider.
SessionLogSupport
Session log support with completeness level.
SizeMappings
Size alias mappings for a provider.

Functions

format_capability
Format a capability struct into the requested output format.
get_capability
Get capability declarations for a provider.
models_to_vec
Convert a slice of string references into a Vec of owned Strings.