Structs
- Feature
Support - A feature that can be either natively supported by the provider or implemented by the wrapper.
- Features
- All feature flags for a provider.
- Provider
Capability - Full capability declaration for a provider.
- Session
LogSupport - Session log support with completeness level.
- Size
Mappings - Size alias mappings for a provider.
Functions
- format_
capability - Format a capability struct into the requested output format.
- get_
capability - Get capability declarations for a provider.
- models_
to_ vec - Convert a slice of string references into a Vec of owned Strings.